| portvine_roll-class | R Documentation |
estimate_risk_roll()The main output class for the function estimate_risk_roll()is
portvine_roll but in the conditional case
the child class cond_portvine_roll with some extra slots (below visible
by the !C!) is returned.
## S4 method for signature 'portvine_roll'
show(object)
## S4 method for signature 'cond_portvine_roll'
show(object)
## S4 method for signature 'portvine_roll'
summary(object)
## S4 method for signature 'cond_portvine_roll'
summary(object)
object |
An object of class |
For easy access for the most important slots and some filtering functionality
have a look at the accessor methods risk_estimates(), fitted_vines(),
fitted_marginals().
object of class portvine_roll
object of class cond_portvine_roll
risk_estimatesdata.table with the columns risk_measure,
risk_est, alpha, row_num, vine_window and realized (here all
samples also in the conditional case are used)
fitted_marginalsnamed list with an entry for each asset containing a
rugarch::ugarchroll class object that encompasses the marginal model fit.
fitted_vineslist of rvinecopulib::vinecop class objects each entry
corresponds to one vine window.
marginal_settingscontaining the specification used for the ARMA-GARCH
fitting i.e. marginal models. Is of class marginal_settings.
vine_settingscontaining the specifications used for the vine fitting.
Is of class vine_settings.
risk_measuresa character vector displaying the estimated risk measures.
alphanumeric vector in (0,1) displaying the confidence levels used when estimating the risk measures.
weightsthe numeric positive weights of the assets. (Matrix with each row corresponding to one vine window) The weights of conditional variables are always 0.
cond_estimationlogical value indicating whether the conditional estimation approach for the risk measures was used.
n_samplespositive numeric count displaying how many return samples were used for the risk measure estimation.
time_takennumeric value displaying how many minutes the whole estimation process took.
cond_risk_estimates!C! data.table with the same columns as the
risk_estimate slot has + the additional conditional columns with the
respective conditioning value and the column character cond_u that
indicates the used conditional quantile level or the conditional value
corresponding to the residual one time unit prior with "prior_resid" or
the realized residual with "resid".
cond_vars!C! character vector with the names of the variables that were used to sample conditionally from.
cond_u!C! a numeric vector specifying the corresponding quantiles in (0,1) of the conditional variable(s) conditioned on which the conditional risk measures were calculated.
estimate_risk_roll(), risk_estimates(), fitted_vines(),
fitted_marginals()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.