| vine_settings-class | R Documentation |
Specify which vine copula models are
fitted and how often they are refit as well as how big the training data
set is. Remember that the estimation process is done in a rolling window
fashion and the arguments (train and refit size) will have to match with
the arguments of the also to be specified marginal_settings.
vine_settings(train_size, refit_size, family_set = "all", vine_type = "rvine")
## S4 method for signature 'vine_settings'
show(object)
train_size |
equivalent to the slot definition below |
refit_size |
equivalent to the slot definition below |
family_set |
equivalent to the slot definition below |
vine_type |
equivalent to the slot definition below |
object |
An object of class |
Object of class vine_settings
vine_settings(): Class constructor taking the arguments
specified in the slots below
train_sizePositive count specifying the training data size.
refit_sizePositive count specifying for how many periods a vine is used
family_setCharacter vector specifying the family of copulas that are
used. For possible choices see rvinecopulib::bicop. Note for conditional
sampling just parametric copula families are possible so do not use the
family arguments all and tll.
vine_typecharacter value that specifies which vine class should be
fitted. Possible choices right now are rvine (regular vine) and dvine
(drawable vine).
marginal_settings
# the most basic initialization
vine_settings(100, 25)
# some individual note
vine_settings(
train_size = 100, refit_size = 20,
family_set = c("gumbel", "joe"),
vine_type = "dvine"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.